@@ -1,5 +1,6 @@
-`title.control` <-
-function(text = NULL,
+## title.control.R
+
+title.control <- function(text = NULL,
                           cex = 1.5,
                           between = if(is.null(text)) 0 else 1)
   ## Author: Rene Locher
@@ -12,3 +13,4 @@ function(text = NULL,
                 between = between))
   } ## title.control
 
+
